<TS language="da" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Om Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Opret en ny adresse</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiér den valgte adresse til systemets udklipsholder</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiér</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Vis &amp;QR kode</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Signerer en meddelelse for at bevise du ejer en Gridcoin adresse</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signere &amp; Besked</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Bekræft en meddelelse for at sikre, den blev underskrevet med en specificeret Gridcoin adresse</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Bekræft Meddelse</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Slet den markerede adresse fra listen</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Adressebog</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Dette er dine Gridcoin adresser til at modtage betalinger. Du ønsker måske at give en anden en til af hver afsender, så du kan holde styr på hvem der betaler dig.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slet</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiér &amp;mærkat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redigér</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Eksporter Adresse Bog</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Fejl ved eksportering</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kunne ikke skrive til fil %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Mærkat</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen mærkat)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Adgangskodedialog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Indtast adgangskode</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Ny adgangskode</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Gentag ny adgangskode</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Deaktivere trivielle sendmoney når OS konto er kompromitteret. Giver ingen reel sikkerhed.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Kun til renteberegning</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Indtast det nye kodeord til tegnebogen.&lt;br/&gt;Brug venligst et kodeord på &lt;b&gt;ti eller flere tilfældige tegn&lt;/b&gt; eller &lt;b&gt;otte eller flere ord&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Kryptér tegnebog</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Denne funktion har brug for din tegnebogs adgangskode for at låse tegnebogen op.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Lås tegnebog op</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Skift adgangskode</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Indtast den gamle og den nye adgangskode til tegnebogen.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bekræft tegnebogskryptering</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Advarsel: Hvis du krypterer din tegnebog og mister din adgangskode, vil du &lt;b&gt; miste alle dine mønter &lt;/ b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Er du sikker på, at du ønsker at kryptere din tegnebog?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Tegnebog krypteret</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin lukker nu for at afslutte krypteringen. Husk at en krypteret  tegnebog ikke fuldt ud beskytter dine mønter mod at blive stjålet af malware som har inficeret din computer.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>VIGTIGT: Enhver tidligere sikkerhedskopi, som du har lavet af tegnebogsfilen, bør blive erstattet af den nyligt genererede, krypterede tegnebogsfil. Af sikkerhedsmæssige årsager vil tidligere sikkerhedskopier af den ikke-krypterede tegnebogsfil blive ubrugelige i det øjeblik, du starter med at anvende den nye, krypterede tegnebog.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Tegnebogskryptering mislykkedes</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Tegnebogskryptering mislykkedes på grund af en intern fejl. Din tegnebog blev ikke krypteret.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>De angivne adgangskoder stemmer ikke overens.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Tegnebogsoplåsning mislykkedes</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Den angivne adgangskode for tegnebogsdekrypteringen er forkert.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Tegnebogens adgangskode blev ændret.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Advarsel: Caps Lock-tasten er aktiveret!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Der opstod en fejl under forsøg på at gemme dataene i tegnebogen til den nye placering.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Tegnebog</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oversigt</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Vis generel oversigt over tegnebog</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Send mønter til en Gridcoin adresse</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Modtag</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Vis listen over adresser for modtagne betalinger</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Gennemse transaktionshistorik</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Redigere listen over gemte adresser og etiketter</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Afslut program</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Om Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Vis oplysninger om Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Indstillinger…</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Ændre indstillingsmuligheder for Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Vis / skjul</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Kryptér tegnebog…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Skift adgangskode…</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Skift adgangskode anvendt til tegnebogskryptering</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>Lås tegnebog op</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Lås tegnebog</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Lås tegnebog</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Lås tegnebog</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signér &amp;besked…</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificér besked…</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Eksporter...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksportere data i den aktuelle fane til en fil</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Fejlsøgningsvindue</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Åbn fejlsøgnings- og diagnosticeringskonsollen</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Opsætning</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[testnetværk]</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Gridcoin klient</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Opdateret</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Indhenter…</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Sidst modtagne blok blev genereret %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Denne transaktion er over grænsen størrelse. Du kan stadig sende det for et gebyr på %1, der går til de noder, der behandler din transaktion og hjælper med at støtte netværket. Ønsker du at betale gebyret?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Bekræft transaktionsgebyr</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Afsendt transaktion</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Indgående transaktion</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI håndtering</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI kan ikke tolkes! Dette kan skyldes en ugyldig Gridcoin adresse eller misdannede URI parametre.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Tegnebog er &lt;b&gt;krypteret&lt;/b&gt; og i øjeblikket &lt;b&gt;låst&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Sikkerhedskopier Tegnebog</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Tegnebogsdata (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Sikkerhedskopiering Mislykkedes</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Der opstod en fejl under forsøg på at gemme data i tegnebogen til den nye placering.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Netværksadvarsel</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Mængde:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Beløb:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Gebyr:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Mønt Kontrol</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lav Udgangseffekt:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Efter gebyr:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Byttepenge:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløb</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bekræftelser</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bekræftet</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Mærkat</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiér adresse</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiér mærkat</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiér beløb</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopiér transaktions-ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiér mængde</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiér gebyr</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiér eftergebyr</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiér byte</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Lav udgangseffekt</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiér byttepenge</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nej</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Denne etiket bliver rød, hvis transaktionen størrelse er større end 10000 byte.
 
Det betyder, at et gebyr på mindst %1 per kb er påkrævet.

Kan variere + / - 1 byte per indgang.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Denne etiket bliver rød, hvis nogen modtager et beløb, der er mindre end %1.
 
Det betyder, at et gebyr på mindst %2 er påkrævet. 
 
Beløb under 0,546 gange det minimale gebyr er vist som DUST.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Denne etiket bliver rød, hvis ændringen er mindre end %1. 
 
Det betyder, at et gebyr på mindst %2 er påkrævet.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen mærkat)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>byttepenge fra %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(byttepange)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Redigér adresse</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Mærkat</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Etiketten er forbundet med denne post i adressekartoteket</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>Adressen er forbundet med denne post i adressekartoteket. Dette kan kun ændres til sende adresser.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresse</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Ny modtagelsesadresse</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Ny afsendelsesadresse</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Redigér modtagelsesadresse</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Redigér afsendelsesadresse</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Den indtastede adresse "%1" er ikke en gyldig Gridcoin adresse.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Den indtastede adresse “%1” er allerede i adressebogen.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kunne ikke låse tegnebog op.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Ny nøglegenerering mislykkedes.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>Usage:</source>
        <translation>Anvendelse:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>Kommandolinjeparametrene</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Generelt</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Netværk</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Konfigurér port vha. &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Automatisk start Gridcoin efter at have logget ind på systemet.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Start Gridcoin ved systems login</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Automatisk åbne Gridcoin klient-port på routeren. Dette virker kun, når din router understøtter UPnP og er det er aktiveret.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>IP-adressen på proxy (f.eks 127.0.0.1)</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Port for proxyen (fx 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimer i stedet for at afslutte programmet, når vinduet lukkes. Når denne indstilling er valgt, vil programmet kun blive lukket, når du har valgt Afslut i menuen.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>Sproget i brugergrænsefladen kan indstilles her. Denne indstilling vil træde i kraft efter genstart af Gridcoin tegnebog.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Få vist Gridcoin adresser på listen over transaktioner eller ej.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>Vis adresser i transaktionsliste</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Vindue</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Anvend</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Vis kun et statusikon efter minimering af vinduet.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimér til statusfeltet i stedet for proceslinjen</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimér ved lukning</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Visning</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Sprog for brugergrænseflade:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Enhed, som beløb vises i:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Vælg standard for underopdeling af enhed, som skal vises i brugergrænsefladen og ved afsendelse af bitcoins.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annullér</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standard</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Denne indstilling vil træde i kraft efter genstart af Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Den angivne proxy-adresse er ugyldig.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Tilgængelig:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Din nuværende tilgængelige saldo</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Umodne:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>De viste oplysninger kan være forældet. Din tegnebog synkroniserer automatisk med Gridcoin netværket efter en forbindelse er etableret, men denne proces er ikke afsluttet endnu.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Summen af ??transaktioner, der endnu mangler at blive bekræftet, og ikke tæller mod den nuværende balance</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Din nuværende totale saldo</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>QR Kode Dialog</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Betalingsanmodning</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Besked:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Antal:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Gem Som...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Fejl kode URI i QR kode.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Det indtastede beløb er ugyldig, venligst tjek igen.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>Resulterende URI for lang, prøv at reducere teksten til etiketten / besked.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Gem QR kode</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Klientversion</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Opstartstidspunkt</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Antal forbindelser</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokkæde</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Nuværende antal blokke</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Tidsstempel for seneste blok</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Åbn</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Ryd</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsol</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Netværkstrafik</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totaler</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Indkommende:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Udgående:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Fejlsøgningslogfil</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Ryd konsol</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>På testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Estimeret antal blokke</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Åbn Gridcoin debug logfilen fra den nuværende data mappe. Dette kan tage et par sekunder for store logfiler.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Kommandolinjeparametrene</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Klientnavn</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Brug op- og ned-piletasterne til at navigere i historikken og &lt;b&gt;Ctrl-L&lt;/b&gt; til at rydde skærmen.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Tast &lt;b&gt;help&lt;/b&gt; for en oversigt over de tilgængelige kommandoer.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Send bitcoins</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Inputs…</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>valgt automatisk</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Utilstrækkelige midler!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Mængde:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Beløb:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Gebyr:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lav udgangseffekt</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nej</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Efter gebyr:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Skift</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>Ændre adresse</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Fjern alle transaktions omkostnings felter </translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Send til flere modtagere på en gang</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Tilføj &amp;modtager</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Ryd &amp;alle</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Bekræft afsendelsen</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Afsend</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiér mængde</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiér beløb</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiér gebyr</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiér eftergebyr</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiér byte</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopier lav produktion</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiér byttepenge</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; til %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Bekræft afsendelse af bitcoins</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Er du sikker på du vil sende %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>og</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Modtagerens adresse er ikke gyldig. Tjek venligst adressen igen.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Beløbet til betaling skal være større end 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Beløbet overstiger din saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Totalen overstiger din saldo, når transaktionsgebyret på %1 er inkluderet.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Duplikeret adresse fundet. Du kan kun sende til hver adresse en gang pr. afsendelse.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Fejl: Transaktion oprettelse mislykkedes.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Fejl: Transaktionen blev afvist. Dette kan ske, hvis nogle af mønterne i din tegnebog allerede er blevet brugt, som hvis du brugte en kopi af wallet.dat og mønterne blev brugt i kopien, men ikke markeret som brugt her.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen mærkat)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>ADVARSEL: Ugyldig Gridcoin adresse</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>ADVARSEL: ukendt adresse forandring</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Beløb:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Betal &amp;til:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Besked:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Mærkat:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Indsæt adresse fra udklipsholderen</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Vælg adresse fra adressebogen</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Fjern denne modtager</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Indtast en mærkat for denne adresse for at føje den til din adressebog</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signaturer – Underskriv/verificér en besked</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Singér besked</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Du kan underskrive beskeder med dine Bitcoin-adresser for at bevise, at de tilhører dig. Pas på ikke at underskrive noget vagt, da phisingangreb kan narre dig til at overdrage din identitet. Underskriv kun fuldt detaljerede udsagn, du er enig i.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Vælg en adresse fra adressebogen</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Indsæt adresse fra udklipsholderen</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Indtast her beskeden, du ønsker at signere</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopiér den nuværende signatur til systemets udklipsholder</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Underskriv brevet for at bevise du ejer denne Gridcoin adresse</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signér &amp;besked</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Nulstil alle “signér besked”-felter</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Ryd &amp;alle</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificér besked</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Indtast den underskrevne adresse, beskeden (inkluder linjeskift, mellemrum mv. nøjagtigt, som de fremgår) og underskriften for at verificére beskeden. Vær forsigtig med ikke at lægge mere i underskriften end besked selv, så du undgår at blive narret af et man-in-the-middle-angreb.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Kontroller meddelelsen for at sikre, at den blev indgået med den angivne Gridcoin adresse</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Nulstil alle “verificér besked”-felter</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klik “Signér besked” for at generere underskriften</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Indtast Gridcoin underskrift</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Den indtastede adresse er ugyldig.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Tjek venligst adressen og forsøg igen.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Den indtastede adresse henviser ikke til en nøgle.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Tegnebogsoplåsning annulleret.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Den private nøgle for den indtastede adresse er ikke tilgængelig.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Signering af besked mislykkedes.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Besked signeret.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Signaturen kunne ikke afkodes.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Tjek venligst signaturen og forsøg igen.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Signaturen passer ikke overens med beskedens indhold.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Verificering af besked mislykkedes.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Besked verificeret.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Åben indtil %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>konflikt</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/ubekræftet</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 bekræftelser</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, er ikke blevet transmitteret endnu</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Kilde</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Fra</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ukendt</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Til</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>egen adresse</translation>
    </message>
    <message>
        <source>label</source>
        <translation>mærkat</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kredit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>ikke accepteret</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaktionsgebyr</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Nettobeløb</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Besked</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløb</translation>
    </message>
    <message>
        <source>true</source>
        <translation>sand</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falsk</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transaktionsdetaljer</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Denne rude viser en detaljeret beskrivelse af transaktionen</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløb</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Åben indtil %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Ubekræftet</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Bekræftet (%1 bekræftelser)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Konflikt</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Genereret, men ikke accepteret</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Modtaget med</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Modtaget fra</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendt til</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Betaling til dig selv</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transaktionsstatus. Hold musen over dette felt for at vise antallet af bekræftelser.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Dato og klokkeslæt for modtagelse af transaktionen.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Transaktionstype.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Destinationsadresse for transaktion.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Beløb trukket fra eller tilføjet balance.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>I dag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Denne uge</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Denne måned</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Sidste måned</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>I år</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Interval…</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Modtaget med</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendt til</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Til dig selv</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andet</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimumsbeløb</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiér adresse</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiér mærkat</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiér beløb</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopiér transaktions-ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Redigér mærkat</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Vis transaktionsdetaljer</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Exportere transaktionsdata</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bekræftet</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Mærkat</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløb</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Fejl exporting</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kunne ikke skrive til filen %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Interval:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>til</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Sender...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Der opstod en fejl ved angivelse af RPC-porten %u til at lytte på IPv6, falder tilbage til IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Der opstod en fejl ved angivelse af RPC-porten %u til at lytte på IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Anvendelse:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Liste over kommandoer</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Få hjælp til en kommando</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Advarsel: -paytxfee er sat meget højt! Dette er det gebyr du vil betale, hvis du sender en transaktion.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Advarsel: wallet.dat ødelagt, data reddet! Oprindelig wallet.net gemt som wallet.{timestamp}.bak i %s; hvis din saldo eller dine transaktioner er forkert, bør du genskabe fra en sikkerhedskopi.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Advarsel: fejl under læsning af wallet.dat! Alle nøgler blev læst korrekt, men transaktionsdata eller adressebogsposter kan mangle eller være forkerte.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Fejl: Transaktion oprettelse mislykkedes</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Fejl: Transaktionen blev afvist. Dette kan ske, hvis nogle af mønterne i din pung allerede er blevet brugt, som hvis du brugte en kopi af wallet.dat og mønterne blev brugt i kopien, men ikke markeret her.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Lytning på enhver port mislykkedes. Brug -listen=0, hvis du ønsker dette.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>For at bruge %s mulighed</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Du skal angive rpcpassword=&lt;password&gt; i konfigurationsfilen:
%s
Hvis filen ikke eksisterer, opret den og giv ingen andre end ejeren læserettighed.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Ugyldigt beløb for -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Ugyldigt beløb for -mininput = &lt;beløb&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Wallet %s placeret udenfor data mappe %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Bekræfter database integritet ...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Fejl initialisering database miljø %s! For at gendanne, BACKUP denne mappe, og derefter fjern alt bortset fra wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat ødelagt, redning af data mislykkedes</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Ugyldig -proxy adresse: “%s”</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Ugyldig-tor-adresse: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Kan ikke finde -bind adressen: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Kan ikke finde -externalip adressen: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Ugyldigt beløb for -reservebalance = &lt;beløb&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Fejl ved indlæsning af blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Fejl ved indlæsning af wallet.dat: Tegnebog ødelagt</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Fejl ved indlæsning af wallet.dat: Wallet kræver en nyere version af Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Det er nødvendig for wallet at blive omskrevet: Genstart Gridcoin for fuldføre</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Fejl ved indlæsning af wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Import af bootstrap blockchain datafil.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Indlæser adresser…</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Fejl: kunne ikke starte node</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Kunne ikke binde sig til %s på denne computer. Gridcoin kører sikkert allerede.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Kunne ikke tildele %s på denne computer (bind returnerede fejl %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Fejl: Wallet låst, ude af stand til at skabe transaktion</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Fejl: Pung låst for at udregne rente, ude af stand til at skabe transaktion.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Fejl: Denne transaktion kræver et transaktionsgebyr på mindst %s på grund af dens størrelse, kompleksitet, eller anvendelse af nylig modtaget midler</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Sender...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Ugyldigt beløb</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Advarsel: Kontroller venligst, at computerens dato og klokkeslæt er korrekt! Hvis dit ur er forkert vil Gridcoin ikke fungere korrekt.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Advarsel: Diskplads lav!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Ukendt netværk anført i -onlynet: “%s”</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Manglende dækning</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Indlæser blokindeks…</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Indlæser tegnebog…</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Kan ikke skrive standardadresse</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Genindlæser…</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Indlæsning gennemført</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
</context>
</TS>